pylbm.elements.Cylinder\_Triangle.change\_of\_variables
=======================================================

.. currentmodule:: pylbm.elements

.. automethod:: Cylinder_Triangle.change_of_variables